#
# spec file for package ruby2.2
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ruby2.2

####
#!!!
#!!! when updating, check versions of embedded rubygems in package stdlib below
#!!!
####

%define patch_level p0
Version:        2.2.3
Release:        5.26
# make the exported API version explicit
%define api_version 2.2.0
%define rb_binary_suffix .ruby2.2
%define rb_soname ruby2.2

# ruby-macros and ruby-common version
%define rpm_macros_version 3

#
%define pkg_version 2.2.3
%define libname libruby2_2-2_2
# keep in sync with macro file!
%define rb_ver  %{api_version}
%define rb_arch %(echo %{_target_cpu}-linux-gnu | sed -e "s/ppc/powerpc/")
%define rb_arch_short %(echo %{_target_cpu}-linux | sed -e "s/ppc/powerpc/ ; s/i[0-9]86/x86/")
%define rb_libdir                         %{_libdir}/ruby/%{rb_ver}/
%define rb_archdir                        %{_libdir}/ruby/%{rb_ver}/%{rb_arch}
%define rb_extdir                         %{_libdir}/ruby/gems/%{rb_ver}/extensions/
%define rb_extarchdir                     %{_libdir}/ruby/gems/%{rb_ver}/extensions/%{rb_arch_short}/
%define rb_extversionedarchdir            %{_libdir}/ruby/gems/%{rb_ver}/extensions/%{rb_arch_short}/%{rb_ver}
%define rb_extdocdir                      %{_libdir}/ruby/gems/%{rb_ver}/doc/extensions
%define rb_extarchdocdir                  %{_libdir}/ruby/gems/%{rb_ver}/doc/extensions/%{rb_arch_short}

# keep in sync with macro file!
#
# from valgrind.spec
%ifarch %ix86 x86_64 ppc ppc64
%define use_valgrind 1
%endif
# see https://bugs.ruby-lang.org/issues/8000 - might come back
#if 0%{?suse_version} && 0%{?suse_version} < 1230
%bcond_without tk_version_supported
#endif
# turn on testsuite by default. we dont hard fail anyway.
%bcond_without run_tests

#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  awk
BuildRequires:  gdbm-devel
BuildRequires:  libffi-devel
BuildRequires:  libyaml-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  readline-devel
BuildRequires:  timezone
%if %{with tk_version_supported}
BuildRequires:  tk-devel
%endif
BuildRequires:  zlib-devel
# this requires is needed as distros older than 11.3 have a buildignore on freetype2, without this the detection of the tk extension fails
BuildRequires:  freetype2-devel
%if 0%{?suse_version} > 1010
BuildRequires:  xorg-x11-libX11-devel
%else
BuildRequires:  xorg-x11-devel
%endif
%if 0%{?use_valgrind}
%if 0%{?suse_version} > 1021
BuildRequires:  valgrind-devel
%else
BuildRequires:  valgrind
%endif
%endif
BuildRequires:  xz
Provides:       ruby(abi) = %{rb_ver}
%if 0%{?suse_version} > 1130
Conflicts:      ruby(abi) = %{rb_ver}
%endif
Provides:       ruby22  = %{version}-%{release}
Requires:       %{libname} = %{version}
Requires:       %{name}-stdlib = %{version}
PreReq:         update-alternatives
BuildRequires:  update-alternatives
Requires:       ruby-common

#
Url:            http://www.ruby-lang.org/
Source:         http://cache.ruby-lang.org/pub/ruby/2.2/ruby-%{version}.tar.xz
Source1:        generate_rubygemprovides.awk
#
Source2:        %{name}.macros
Source3:        %{name}-default.macros
Source99:       %{name}-rpmlintrc

# to be regenerated patches?
Source100:      rubygems-1.5.0_buildroot.patch
Source101:      ruby2.2.x_rbinstall_gem_buildroot.patch

Patch0:         ruby-1.9.2p290_tcl_no_stupid_rpaths.patch
Patch1:         make-gem-build-reproducible.patch
#
Summary:        An Interpreted Object-Oriented Scripting Language
License:        BSD-2-Clause or Ruby
Group:          Development/Languages/Ruby

%description
Ruby is an interpreted scripting language for quick and easy
object-oriented programming.  It has many features for processing text
files and performing system management tasks (as in Perl).  It is
simple, straight-forward, and extensible.

* Ruby features:

- Simple Syntax

- *Normal* Object-Oriented features (class, method calls, for
   example)

- *Advanced* Object-Oriented features(Mix-in, Singleton-method, for
   example)

- Operator Overloading

- Exception Handling

- Iterators and Closures

- Garbage Collection

- Dynamic Loading of Object Files (on some architectures)

- Highly Portable (works on many UNIX machines; DOS, Windows, Mac,
BeOS, and more)

%package -n %{libname}
Summary:        Dynamic runtime library for Ruby
Group:          System/Libraries

%description -n %{libname}
Dynamic runtime library libruby2.1.so.2.0.0 for Ruby

%package doc
Summary:        Documentation and samples for Ruby
Group:          Development/Languages/Ruby

%description doc
Documentation and samples for Ruby

%package stdlib
Summary:        The Ruby standard library
Group:          Development/Languages/Ruby
Provides:       ruby-stdlib = %{version}-%{release}
Requires:       %{libname} = %{version}

################################
# generate provides for embedded rubygems
# must be 'manually' generated since
# - the final .gemspec files are created during %build and %install
# - the usual means to generate provides for rubygems is using ruby
#   and ruby is not available while building ruby :-/

%define gen_embedded_provides4() %(awk -f %{S:1} -- %api_version %arch %1 %2 %3 %4)
%define gen_embedded_provides5() %(awk -f %{S:1} -- %api_version %arch %1 %2 %3 %4 %5)
%gen_embedded_provides4 io-console 0 4 2
%gen_embedded_provides4 json 1 8 1
%gen_embedded_provides4 minitest 4 7 5
%gen_embedded_provides4 psych 2 0 3
%gen_embedded_provides4 rake 10 4 2
%gen_embedded_provides4 rdoc 4 2 0
%gen_embedded_provides5 test-unit 2 1 1 0

################################

%description stdlib
The Ruby standard library

%package devel
Summary:        Development files to link against Ruby
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}
Provides:       rubygems = 2.4.5
Provides:       rubygems_with_buildroot_patch

%description devel
Development files to link against Ruby.

%package devel-extra
Summary:        Special development files of ruby, normally not installed
Group:          Development/Languages/Ruby
Requires:       %{name}-devel = %{version}

%description devel-extra
Development files to link against Ruby.

%if %{with tk_version_supported}
%package tk
Summary:        TCL/TK bindings for Ruby
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}

%description tk
TCL/TK bindings for Ruby
%endif

%package doc-ri
Summary:        Ruby Interactive Documentation
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}
%if 0%{?suse_version} >= 1121
BuildArch:      noarch
%endif

%description doc-ri
This package contains the RI docs for ruby

%package doc-html
Summary:        This package contains the HTML docs for ruby
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}
%if 0%{?suse_version} >= 1121
BuildArch:      noarch
%endif

%description doc-html
This package contains the HTML docs for ruby

%package examples
Summary:        Example scripts for ruby
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}
%if 0%{?suse_version} >= 1121
BuildArch:      noarch
%endif

%description examples
Example scripts for ruby

%package test-suite
Requires:       %{name} = %{version}
Summary:        An Interpreted Object-Oriented Scripting Language
Group:          Development/Languages/Ruby
%if 0%{?suse_version} >= 1121
BuildArch:      noarch
%endif

%description test-suite
Ruby is an interpreted scripting language for quick and easy
object-oriented programming.  It has many features for processing text
files and performing system management tasks (as in Perl).  It is
simple, straight-forward, and extensible.

* Ruby features:

- Simple Syntax

- *Normal* Object-Oriented features (class, method calls, for
   example)

- *Advanced* Object-Oriented features(Mix-in, Singleton-method, for
   example)

- Operator Overloading

- Exception Handling

- Iterators and Closures

- Garbage Collection

- Dynamic Loading of Object Files (on some architectures)

- Highly Portable (works on many UNIX machines; DOS, Windows, Mac,
BeOS, and more)

%prep
%setup -q -n ruby-%{pkg_version}
%patch0
%patch1 -p1
find sample -type f -print0 | xargs -r0 chmod a-x
grep -Erl '^#! */' benchmark bootstraptest ext lib sample test \
  | xargs -r perl -p -i -e 's|^#!\s*\S+(\s+.*)?$|#!/usr/bin/ruby%{rb_binary_suffix} $1|'

%build
# iseq.c needs -fno-strict-aliasing
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
  --program-suffix="%{rb_binary_suffix}"  \
  --with-soname=%{rb_soname} \
  --target=%{_target_platform} \
  %if 0%{?use_valgrind}
  --with-valgrind \
  %endif
  --with-mantype=man \
  --enable-shared \
  --disable-static \
  --disable-rpath
%{__make} all V=1

%install
%makeinstall V=1
echo "%defattr(-,root,root,-)" > devel-extra-excludes
echo "%defattr(-,root,root,-)" > devel-extra-list
for i in iseq.h insns.inc insns_info.inc revision.h version.h  thread_pthread.h \
  ruby_atomic.h method.h internal.h id.h vm_core.h vm_opts.h node.h eval_intern.h vm_debug.h; do
  install -m 644 $i %{buildroot}%{_includedir}/ruby-%{rb_ver}/
  echo "%exclude %{_includedir}/ruby-%{rb_ver}/$i" >> devel-extra-excludes  
  echo "%{_includedir}/ruby-%{rb_ver}/$i" >> devel-extra-list
done

# Create gem native extensions dir
# use shell scripting here as we're executing the just installed binary
%define rb_binary %{buildroot}/usr/bin/ruby -I %{buildroot}%{rb_libdir} -I %{buildroot}%{rb_archdir}
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}

install -D -m 0644 %{S:2} %{buildroot}/etc/rpm/macros.suse-ruby2.2
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
%if "%{rb_default_ruby_suffix}" == "%{rb_soname}"
  install -D -m 0644 %{S:3} %{buildroot}/etc/rpm/macros.suse-ruby2.2-default
  for bin in %{buildroot}%{_bindir}/{erb,gem,irb,ruby}%{rb_binary_suffix} ; do
    # yes really hard links
    ln $bin ${bin%%%{rb_binary_suffix}}
  done
  for man in %{buildroot}%{_mandir}/man1/*%{rb_binary_suffix}.1* ; do
    # yes really hard links
    # TODO: this is dangerous as we cant anc
    ln $man ${man%%%{rb_binary_suffix}.1}.1
  done
  ln -s lib%{rb_soname}.so %{buildroot}%{_libdir}/libruby.so
%endif
for bin in rake rdoc ri; do
  # dummy
  mv %{buildroot}%_bindir/${bin}%{rb_binary_suffix} %{buildroot}%_bindir/$bin.ruby%{rb_binary_suffix}
  #
  ln -s $bin                      %{buildroot}%{_sysconfdir}/alternatives/$bin
  ln -s %{_sysconfdir}/alternatives/$bin %{buildroot}%_bindir/$bin
  #
  ln -s ${bin}%{rb_binary_suffix} %{buildroot}%{_sysconfdir}/alternatives//$bin%{rb_binary_suffix}
  ln -s %{_sysconfdir}/alternatives/$bin%{rb_binary_suffix} %{buildroot}%_bindir/$bin%{rb_binary_suffix}
done
install -dD %{buildroot}%{rb_extdir} %{buildroot}%{rb_extarchdir} %{buildroot}%{rb_extversionedarchdir} %{buildroot}%{rb_extarchdocdir}
chmod -vR go-w %{buildroot}%{_libdir}/ruby
# clean up intree certs boo# 900932
rm -v %{buildroot}%{rb_libdir}/rubygems/ssl_certs/{Class3PublicPrimaryCertificationAuthority.pem,DigiCertHighAssuranceEVRootCA.pem,EntrustnetSecureServerCertificationAuthority.pem,GeoTrustGlobalCA.pem}

%post
for bin in rake rdoc ri; do
  /usr/sbin/update-alternatives --install \
    %{_bindir}/$bin $bin %{_bindir}/$bin.ruby%{rb_binary_suffix} 2
  /usr/sbin/update-alternatives --install \
    %{_bindir}/$bin%{rb_binary_suffix} $bin%{rb_binary_suffix} %{_bindir}/$bin.ruby%{rb_binary_suffix} 2
done

%preun
if [ "$1" = 0 ] ; then
  for bin in rake rdoc ri; do
    /usr/sbin/update-alternatives --remove $bin %{_bindir}/$bin.ruby%{rb_binary_suffix}
    /usr/sbin/update-alternatives --remove $bin%{rb_binary_suffix} %{_bindir}/$bin.ruby%{rb_binary_suffix}
  done
fi

%if %{with run_tests}
%check
%ifarch armv7l armv7hl armv7hnl
# test_call_double(DL::TestDL) fails on ARM HardFP
# http://bugs.ruby-lang.org/issues/6592
DISABLE_TESTS="-x test_dl2.rb $DISABLE_TESTS"

# Workaround OpenSSL::TestPKeyRSA#test_sign_verify_memory_leak timeouts on ARM.
# https://bugs.ruby-lang.org/issues/9984
sed -i -e 's|20_000|10_000|g' test/openssl/test_pkey_rsa.rb
%endif
# Allow MD5 in OpenSSL.
# https://bugs.ruby-lang.org/issues/9154
export OPENSSL_ENABLE_MD5_VERIFY=1
export LD_LIBRARY_PATH="$PWD"
# we know some tests will fail when they do not find a /usr/bin/ruby
make check V=1 $DISABLE_TESTS ||:
%endif

%post -n %{libname}
/sbin/ldconfig

%postun -n %{libname}
/sbin/ldconfig

%files
%defattr(-,root,root,-)
%ghost %{_sysconfdir}/alternatives/rake*
%ghost %{_sysconfdir}/alternatives/rdoc*
%ghost %{_sysconfdir}/alternatives/ri*
%{_bindir}/erb*
%{_bindir}/gem*
%{_bindir}/irb*
%{_bindir}/rake*
%{_bindir}/rdoc*
%{_bindir}/ri*
%{_bindir}/ruby*
%if %{with tk_version_supported}
%exclude %{rb_libdir}/multi-tk.rb
%exclude %{rb_libdir}/remote-tk.rb
%exclude %{rb_libdir}/tcltk.rb
%exclude %{rb_libdir}/tk*.rb
%exclude %{rb_libdir}/tk/
%exclude %{rb_libdir}/tkextlib/
%exclude %{rb_archdir}/tcltklib.so
%exclude %{rb_archdir}/tkutil.so
%endif
%{_mandir}/man1/ri*.1*
%{_mandir}/man1/irb*.1*
%{_mandir}/man1/erb*.1*
%{_mandir}/man1/rake*.1*
%{_mandir}/man1/ruby*.1*
%doc ChangeLog  COPYING  COPYING.ja  GPL  KNOWNBUGS.rb  LEGAL  NEWS  README*
%config /etc/rpm/macros.suse-ruby2.2*

%files -n %{libname}
%defattr(-,root,root,-)
%{_libdir}/libruby*.so.*

%files doc
%defattr(-,root,root,-)
%doc doc/* sample/

%files stdlib
%defattr(-,root,root,-)
%{_libdir}/ruby/
%if %{with tk_version_supported}
%exclude %{rb_libdir}/multi-tk.rb
%exclude %{rb_libdir}/remote-tk.rb
%exclude %{rb_libdir}/tcltk.rb
%exclude %{rb_libdir}/tk*.rb
%exclude %{rb_libdir}/tk/
%exclude %{rb_libdir}/tkextlib/
%exclude %{rb_archdir}/tcltklib.so
%exclude %{rb_archdir}/tkutil.so
%endif
%dir %rb_extdir
%dir %rb_extarchdir
%dir %rb_extversionedarchdir
%dir %rb_extdocdir
%dir %rb_extarchdocdir

%files devel -f devel-extra-excludes
%defattr(-,root,root,-)
%{_includedir}/ruby-%{rb_ver}
%{_libdir}/libruby*.so
%{_libdir}/libruby*-static.a
%{_libdir}/pkgconfig/ruby-2.2.pc

%files devel-extra -f devel-extra-list

%if %{with tk_version_supported}
%files tk
%defattr(-,root,root,-)
%{rb_libdir}/multi-tk.rb
%{rb_libdir}/remote-tk.rb
%{rb_libdir}/tcltk.rb
%{rb_libdir}/tk*.rb
%{rb_libdir}/tk/
%{rb_libdir}/tkextlib/
%{rb_archdir}/tcltklib.so
%{rb_archdir}/tkutil.so
%endif

%files doc-ri
%defattr(-,root,root,-)
%dir %{_datadir}/ri/
%{_datadir}/ri/%{rb_ver}/

%changelog
* Wed Aug 19 2015 mrueckert@suse.de
- update to 2.2.3 (boo# 936032)
  - update rubygems to  2.4.5.1. this version fixed CVE-2015-3900.
  - Fix document for Float::MIN and Float::EPSILON.
  - should match only char boundaries in wide character encodings.
    [ruby-core:70220] [Bug #11413]
  - Fixed bad performance in ruby >= 2.2 for Hash with many symbol
    keys
  - target encoding name can be empty now.
    [ruby-core:69841] [Bug #11324]
  - fix Float hash. rb_dbl_hash() returns a Fixnum, but not a long.
    [Bug #9381]
  - raise with messages in UTF-8 encoding.
    [ruby-core:67386] [Bug #10705]
  - handle O_TRUNC correctly [ruby-core:69779] [Bug #11319]
  - FTP close the TCPServer when sending the port fails.
  - (Net::HTTPResponse::Inflater#finish): fix a bug that empty
    gzipped response body causes Zlib::BufError.
    [ruby-core:68846] [Bug #11058]
  - (Net::HTTPResponse#inflater): fix TypeError. An exception
    object might be nil. [ruby-core:68846] [Bug #11058]
  - (module OpenSSL): raise a more helpful exception when verifying
    the peer connection and an anonymous cipher has been selected.
    [ruby-core:68330] [Bug #10910]
  - ruby itself (including numeric.c) is built with strict compile
    options including -std=iso9899:1999, but ext/date is not.  By
    the way -std=iso9899:1999 is not only a warning option but also
    changes behavior like MACRO definitions for example INFINITY.
    [Bug #10906]
  - Fix LocalJumpErrors being raised in OpenSSL tests.
    [ruby-core:70020][Bug #11368]
  - make Timeout::ExitException an alias of Timeout::Error
    [ruby-dev:49179] [Bug #11344]
  - (HTTPResponseTest#test_read_body_content_encoding_deflate_uppercase):
    fix a failure without zlib.
  - copy the arguments to the machine stack before rewinding the
    control frame pointer and leaving the arguments outside valid
    region of the value stack.  [ruby-core:69969] [Bug #11352]
  - CONTENT_ENCODING can be upper case. [ruby-core:69670] [Bug #11285]
    patched by Andy Chu
  - copy the arguments to the machine stack before rewinding the control
    frame pointer and leaving the arguments outside valid region of the
    value stack.  [ruby-core:69969] [Bug #11352]
  - keep the arguments region inside the valid value stack.
    [ruby-core:69969] [Bug #11352]
  - reversed string is not a substring, and should not set coderange of
    the original string.  [ruby-dev:49189] [Bug #11387]
  - pop cmdarg stack for lookahead token.  [ruby-core:70067] [Bug
    [#11380]]
  - Support %%s.%%N.  [ruby-core:68301] [Bug #10904]
  - fix transcoder loading race condition, by waiting in require.
    [ruby-dev:49106] [Bug #11277]
  - check if array size will exceed maximum size to get rid of buffer
    overflow.  [ruby-dev:49043] [Bug #11235]
  - try opening file without gvl not to lock entire process.  [Bug
    [#11060]]
  - split --libs if --libs-only-l option is not available.  patch in
    [ruby-core:69428] by Hans Mackowiak.  [ruby-core:69421] [Bug #11201]
  - out of range NTH_REF is always nil.
  - check overflow of NTH_REF and range.  [ruby-core:69393] [Bug #11192]
  - make public and add length parameter.
  - resolve refined method entry to check if undefined.
    [ruby-core:69064] [Bug #11117]
  - undefined refined method is not callable unless using.
    [ruby-core:69064] [Bug #11117]
  - Fix require paths for released gem.  [fix GH-929] Patch by @voxik
  - Return empty JSON object when passed object is a special const,
    instead of SEGV.  Based patch by Kohei Suzuki (eagletmt).
    [ruby-core:69692] [Bug #11291]
  - relax pattern because long_lived flag and marked flag can be false
    at major GC.  [Bug #10852]
  - use RB_GC_GUARD instead of volatile [ruby-core:69419] [Feature
    [#11198]]
  - ext/openssl/ossl_asn1.c (ossl_asn1_traverse, ossl_asn1_decode,
    ossl_asn1_decode_all): use RB_GC_GUARD instead of volatile
    [ruby-core:69371] [Bug #11185]
  - seek to the file end only when writing (mode:a), not reading
    (mode:a+, read).
  - stop returning false negatives for filenames which are trailing
    substrings of file extensions.  For example, 'b', which a trailing
    substring of ".rb" should not return false. [Bug
    [#11155]][ruby-core:69206]
  - register symbol names as strings first so that r_symlink always
    returns valid names.  [ruby-core:68587] [Bug #10991]
  - bsock_recmvsg_internal needs GC guard for control buffer [Bug
    [#11123]]
  - test if covered for linear objects.  [ruby-core:69052] [Bug #11113]
  - should work even if body-fld-dsp is omitted.  [ruby-core:69093] [Bug
    [#11128]]
  - added documentation for character sequence \' with String#sub [Bug
    [#11132]][ruby-core:69121][fix GH-900][ci skip] Patch by @shishir127
  - Added documentation for rational literal.  [Bug #11075][fix
    GH-885][ci skip] Patch by @shishir127
  - preserve errno before other library calls and use rb_syserr_fail.
    [ruby-core:68531] [Bug #10975]
  - check other events when RETURN is thrown.  [Bug #10724]
  - fix memory leak of addrinfo.  [ruby-dev:48923] [Bug #11051]
  - try magic number only if f_type is included.  [ruby-dev:48913] [Bug
    [#11000]]
  - return filesystem name by statfs/statvfs.  [ruby-core:68624] [Bug
    [#10998]]
  - Symbols are compared by the identities always.  [ruby-core:68767]
    [Bug #11035]
  - use same hash values with Float#hash so that -0.0 and +0.0 will be
    identical.  [ruby-core:68541] [Bug #10979]
  - prohibit from accessing internal objects.  [ruby-core:68348] [Bug
    [#10918]] [ruby-core:58539] [Bug #9144]
  - search the target to break from a block with nested rescue, from the
    nested blocks.  [ruby-core:67765] [Bug #10775] [Fix GH-820]
  - protect value stack from calling other methods during complex
    parameter setting process (splat, kw, and so on).  [Bug #11027]
  - allow symbols to just instance_eval/exec, except for definition of
    singletons.  [ruby-core:68961] [Bug #11086]
  - clear NOFREE flag at embedding as embedded strings no longer refer
    static strings.  [ruby-core:68436] [Bug #10942]
  - use getattrlist() if fgetattrlist() is unavailable, on OSX 10.5.
    [ruby-core:68829] [Bug #11054]
  - replicate env from method object, and allocate the local variable
    area for the iseq local table.  [ruby-core:68673] [Bug #11012]
  - make more realistic data.  [ruby-core:68632] [[Bug #10999]
  - check if the receiver responds to the given method by
    respond_to_missing?.
  - create Method object for method_missing.  [ruby-core:68564] [Bug
    [#10985]]
  - need to check the return value of GLOB_REALLOC().
  - shouldn't create Ruby object before the object system is loaded.
    [ruby-core:68430] [Bug #10941]
  - Check class equality.  (Resolv::DNS::Name#initialize): Normalize
    labels as Resolv::DNS::Label::Str objects.
  - check source type, must be an IO or a String.  [ruby-core:69219]
    [Bug #11159]
  - make dsym_fstrs a hash compared by identity as the keys are unique
    fstrings, to get rid of running hash and compare methods and causing
    new object allocation during garbage collection phase.
    [ruby-dev:48891] [Bug #10933]
  - push and reset cmdarg_stack in lambda body.  [ruby-core:69017] [Bug
    [#11107]]
  - check if a different libruby is loaded by the extension library, and
    then bail out to get rid of very frequent reported stale bug
    reports.
  - show the exact target path in the error message instead of the
    destination parent directory name. [ruby-core:68706].  [Bug #11021]
  - keep sp safe zone to get rid of crash by -fstack-check.
    [ruby-core:68740] [Bug #11030]
  - check also procstat_getvmmap, which is not available on FreeBSD 9.
    [ruby-core:68468] [Bug #10954]
  - use kinfo_getvmmap instead if procstat_getvmmap is not available.
* Fri Jun 19 2015 adrian@suse.de
- fix provided rake and rdoc version
- remove generic rubygem-rake provides
* Thu Apr 16 2015 mrueckert@suse.de
- update to 2.2.2 (bsc# 926974)
  - stricter hostname verification following RFC 6125. with the
    patch provided by Tony Arcieri and Hiroshi Nakamura
    [ruby-core:61545] [Bug #9644] CVE-2015-1855
  - fix segfault by null caused by syntax error. [ruby-core:68851]
    [Bug #10957]
  - parse.y (primary): empty parentheses at cmdarg can be null.
    [ruby-core:68477] [Bug #10957]
  - ext/io/wait/wait.c (io_nread): wrap return value with INT2FIX
    Thanks to Yura Sokolov <funny.falcon@gmail.com>
    [ruby-core:68369] [Bug#10923]
  - test/io/wait/test_io_wait.rb (test_nread_buffered): fix broken
    test
  - vm_eval.c (vm_call_super): search next super class from the
    original class, to get rid of infinite recursion with
    prepending.  a patch by Seiei Higa <hanachin AT gmail.com> at
    [ruby-core:68434].  [ruby-core:68093] [Bug #10847]
  - class.c (rb_prepend_module): need a WB for klass -> origin.
  - ext/fiddle/extconf.rb: needs --enable-shared when linked to
    libruby or fiddle.so.  since --with-static-linked-ext does no
    longer link extensions to ruby program with --enable-shared,
    the only combination needs --enable-static is --disable-shared
    and --with-static-linked-ext.  [ruby-dev:48901] [Bug #10960]
  - ext/fiddle/extconf.rb: make PIC objects if it will be linked as
    a shared object eventually.  [ruby-core:67128]
  - spec/default.mspec: use default configuration file name.
    https://github.com/ruby/rubyspec/commit/cc69f337b06362e5607ffa3e3ad40ef7494960cf
  - spec/default.mspec: remove specific version number.
    https://github.com/ruby/rubyspec/commit/7a909e925c1baa9c700bd44af9241aef6e596714
  - common.mk: use ruby organization for rubyspec.
  For all the changes see /usr/share/doc/packages/ruby2.2/ChangeLog
* Wed Mar 11 2015 mrueckert@suse.de
- while merging the changes with the 2.1 package i noticed 2
  problems:
  - we still rewrote the she bang lines to ruby 2.1.
  - the macro files weren't marked as config.
* Wed Mar 11 2015 mrueckert@suse.de
- Remove the support to have the shared files from ruby-common
  intree again.
* Wed Mar 11 2015 mrueckert@suse.de
- update to 2.2.1
  This release includes the fix for ffi build failure and memory
  leak issue on Symbol GC (See Bug #10686).
  For more details see /usr/share/doc/packages/ruby2.2/ChangeLog
- match the version number in the rubygems provides to what is
  actually shipped with ruby 2.2
* Wed Feb 11 2015 coolo@suse.com
- port make-gem-build-reproducible.patch from ruby 2.1
* Mon Feb  9 2015 coolo@suse.com
- remove upstreamed drop_content_size_check_in_xmlrpc.patch
- add unapplied patches as sources for now to pass source validator,
  we might have use for them later
* Thu Dec 25 2014 mrueckert@suse.de
- tk seems to work now with newer tk versions
- convert the conditional for tk to bcond_with(out)
- buildrequire tk-devel only if we want to build with tk. otherwise
  we get tk built and packaged even if we dont expect it. this
  leads to the rubyX.y-stdlib pulling tk.
* Thu Dec 25 2014 mrueckert@suse.de
- sync spec file with 2.1 branch
* Thu Dec 25 2014 mrueckert@suse.de
- update to 2.2.0 final:
  - Notable Changes since 2.1
  - Incremental GC (YARV Maniacs No.12)
  - Symbol GC (presentation at RubyKaigi 2014)
  - configure –with-jemalloc Feature #9113
  - core libraries:
  - Support Unicode 7.0 #9092
  - New methods:
  - Enumerable#slice_after #9071, Enumerable#slice_when #9826
  - Float#next_float, Float#prev_float #9834
  - File.birthtime, File#birthtime #9647
  - String#unicode_normalize #10084
  - bundled libraries:
  - Update Psych 2.0.8
  - Update Rake 10.4.2
  - Update RDoc 4.2.0
  - Update RubyGems 2.4.5
  - Update test-unit 3.0.8 (removed from repository but bundled
    in tarball)
  - Update minitest 5.4.3 (removed from repository but bundled
    in tarball)
  - Deprecate mathn
  - C API
  - Remove deprecated APIs
  See https://github.com/ruby/ruby/blob/v2_2_0/NEWS for details.
  With those changes, 1557 files changed, 125039 insertions(+),
  74376 deletions(-) from v2.1.0!
* Wed Sep 24 2014 mrueckert@suse.de
- also make the ghost files match what we generate in the rubygem
  based packages
* Wed Sep 24 2014 mrueckert@suse.de
- also provide the %%{_bindir}/$bin%%{rb_binary_suffix} symlinks via
  u-a to be consistent with what gem based packages do.
* Mon Sep 22 2014 mrueckert@suse.de
- update to ruby-2.2.0-r47678
- drop buildroot patches! finally all upstream:
  ruby2.2.x_rbinstall_gem_buildroot.patch
  rubygems-1.5.0_buildroot.patch
* Mon Sep 22 2014 mrueckert@suse.de
- instead of touch for the files in /etc/alternatives. use the
  symlink pointing to itself.
* Fri Sep 19 2014 mrueckert@suse.de
- conflict with our own ruby abi
* Wed Sep 17 2014 mrueckert@suse.de
- only provide the rdoc and ri symlink on newer than sle11
* Wed Sep 17 2014 mrueckert@suse.de
- BR: xz
* Mon Sep 15 2014 mrueckert@suse.de
- the ruby(abi) = $interpreter:$abiversion was not a good idea. rpm
  treats the $interpreter part as epoch. instead we use now:
  $interpreter(abi) = $abiversion
  For MRI it means we are basically back to ruby(abi).
  Examples for alternative ruby interpreters are rubinius(abi) and
  jruby(abi) (bnc#896658)
* Wed Sep  3 2014 mrueckert@suse.de
- also in the awk generated provides we should add the
  intererpreter part to the provides. also remove the old package
  name based provides there.
* Wed Sep  3 2014 mrueckert@suse.de
- fix typo in macro
* Wed Sep  3 2014 mrueckert@suse.de
- update the ruby abi part in the macros
* Wed Sep  3 2014 mrueckert@suse.de
- use the new ruby abi syntax
* Wed Jul 16 2014 mrueckert@suse.de
- added ruby2.2.macros:
  ruby 2.2 specific macros for the macro based expansion
- added ruby2.2-default.macros:
  if ruby 2.2 is default this file will be installed and sets the
  rb_default* variables and rb_build_versions accordingly.
- no longer conflict with the other versioned ruby packages
* Tue Jul 15 2014 mrueckert@suse.de
- now we can configure the default ruby version in the project
  config.
  if the package's rb_soname matches the rb_default_ruby_suffix,
  the package is default and we create the hardlinks for the
  important binaries and the libruby.so symlink.
* Tue Jul 15 2014 mrueckert@suse.de
- require ruby-common already in the main package, not every
  package we build requires ruby-devel
- update the rubygems provides to the actual version
* Wed Jun 25 2014 mrueckert@suse.de
- added ruby2.2.x_rbinstall_gem_buildroot.patch:
  we need to pass the destdir to the Gem.install call inside the
  ruby build process
* Wed Jun 25 2014 mrueckert@suse.de
- first snapshot of 2.2
* Wed Jun 18 2014 mrueckert@suse.de
- %%ix86 architectures are x86 for rubygems
* Wed Jun 18 2014 mrueckert@suse.de
- also package the extensions documentation dir
* Wed Jun 18 2014 mrueckert@suse.de
- no longer share the rb_binary_suffix between the library usage
  and the binary usage. for the library usage we have now
  rb_soname.
- change rb_binary_suffix to .ruby2.1
* Wed Jun 18 2014 mrueckert@suse.de
- also provide libruby.so again:
  too much broken code relies on the existence of it
* Wed Jun 18 2014 mrueckert@suse.de
- also package the extensions dir so we have an owner
* Tue Jun 17 2014 mrueckert@suse.de
- no longer provide the ruby macros
* Sun Jun 15 2014 mrueckert@suse.de
- remove ruby19-export_init_prelude.patch
* Sun Jun 15 2014 mrueckert@suse.de
- dont build ruby-common in here anymore
* Fri May 16 2014 kkaempf@suse.com
- Update to 2.1.2
  - fix for a regression of Hash#reject in Ruby 2.1.1
  - support for build with Readline-6.3 (see Bug #9578)
  - updated bundled version of libyaml with psych
  - some bug fixes.
* Sun Mar  2 2014 kkaempf@suse.com
- make api_version explicit in spec
- adapt versions of embedded gems
* Fri Feb 28 2014 adrian@suse.de
- use api version 2.1.0 again to avoid dependency breakages
* Fri Feb 28 2014 kkaempf@suse.com
- Update to 2.1.1
  Speedup and bugfixes (upstream bug ids):
  - rubygems 2.2.2 (#9489)
  - fix segfault at unpacking modified String (#9478)
  - Struct#send(:setter=, rhs) does not return rhs (#9470)
  - Array#uniq behavior change (#9470)
  - Timeout behavior change (#9470)
  - Hash lookup with #hash and #eql broken (#9470)
  - bigdecimal division issue (#9470)
  - SizedQueue not working (#9470)
  - BidDecimal division (#9316)
  - fix 'gem install --ignore-dependencies' for remote gems  (#9282)
  - Array#to_h should not ignore badly formed elements (#9270)
  - Method#arity for keyword arguments (#8072)
* Sat Feb 15 2014 kkaempf@suse.com
- add internal.h to ruby-devel-extra
* Mon Feb 10 2014 kkaempf@suse.com
- Don't require rpm-with-ruby-provide-hook on SLE11.
  It's not a runtime requirement but a build-time requirement for
  rubygems in SLE11. Buildservice will take care of that.
* Fri Feb  7 2014 coolo@suse.com
- reintroduce update-alternatives for rake, rdoc and ri as those
  can come from more uptodate gems
* Sat Feb  1 2014 coolo@suse.com
- readd old macros - for now at least
* Fri Jan 31 2014 kkaempf@suse.com
- generate provides for embedded rubygems
* Thu Jan 30 2014 kkaempf@suse.com
- merged ruby-common
* Sun Jan 19 2014 kkaempf@suse.com
- new package split - only single Ruby version installable
  ruby - binary
  libruby2_1-2_0 - ruby runtime library
  ruby-stdlib - ruby standard library
  ruby-doc - ruby documentation
  ruby-devel - ruby development
* Sun Jan 19 2014 kkaempf@suse.com
- revert the ruby split (ruby - ruby21)
  rename ruby21 to ruby, integrate 'ruby' and 'ruby-common'
* Thu Jan  9 2014 jreidinger@suse.com
- remove part of rubygems1.5 patch that modify mkmf which is
  already fixed upstream
* Wed Jan  8 2014 kkaempf@suse.com
- fix rb_arch in spec: append -gnu
- fix native gem builds: create gem native extensions dir
* Mon Jan  6 2014 coolo@suse.com
- initial version for ruby 2.1.0 - changes to Ruby 2.0:
  VM (method cache)
  RGenGC (See ko1’s RubyKaigi presentation and RubyConf 2013 presentation)
  refinements #8481 #8571
  syntax changes
  Rational/Complex Literal #8430
  def’s return value #3753
  Bignum
  use GMP #8796
  String#scrub #8414
  Socket.getifaddrs #8368
  RDoc 4.1.0 and RubyGems 2.2.0
  “literal”.freeze is now optimized #9042
  add Exception#cause #8257
  update libraries like BigDecimal, JSON, NKF, Rake, RubyGems, and RDoc
  remove curses #8584
- initial patches:
  drop_content_size_check_in_xmlrpc.patch
  ruby-1.9.2p290_tcl_no_stupid_rpaths.patch
  ruby19-export_init_prelude.patch
  rubygems-1.5.0_buildroot.patch
